==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/NetworkStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkStatusFluent<A extends io.fabric8.openshift.api.model.NetworkStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToClusterNetwork(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public A setToClusterNetwork(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public A addToClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... items);
  public A addAllToClusterNetwork(java.util.Collection<io.fabric8.openshift.api.model.ClusterNetworkEntry> items);
  public A removeFromClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... items);
  public A removeAllFromClusterNetwork(java.util.Collection<io.fabric8.openshift.api.model.ClusterNetworkEntry> items);
  public A removeMatchingFromClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildClusterNetwork instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> getClusterNetwork();
  public java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> buildClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildClusterNetwork(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildFirstClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildLastClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public java.lang.Boolean hasMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public A withClusterNetwork(java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> clusterNetwork);
  public A withClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... clusterNetwork);
  public java.lang.Boolean hasClusterNetwork();
  public A addNewClusterNetwork(java.lang.String cidr,java.lang.Integer hostSubnetLength);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> addNewClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> addNewClusterNetworkLike(io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> setNewClusterNetworkLike(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editClusterNetwork(java.lang.Integer index);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editFirstClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editLastClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public java.lang.Integer getClusterNetworkMTU();
  public A withClusterNetworkMTU(java.lang.Integer clusterNetworkMTU);
  public java.lang.Boolean hasClusterNetworkMTU();
  
  /**
   * This method has been deprecated, please use method buildMigration instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.NetworkMigration getMigration();
  public io.fabric8.openshift.api.model.NetworkMigration buildMigration();
  public A withMigration(io.fabric8.openshift.api.model.NetworkMigration migration);
  public java.lang.Boolean hasMigration();
  public A withNewMigration(java.lang.String networkType);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> withNewMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> withNewMigrationLike(io.fabric8.openshift.api.model.NetworkMigration item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editOrNewMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editOrNewMigrationLike(io.fabric8.openshift.api.model.NetworkMigration item);
  public java.lang.String getNetworkType();
  public A withNetworkType(java.lang.String networkType);
  public java.lang.Boolean hasNetworkType();
  
  /**
   * Method is deprecated. use withNetworkType instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkType(java.lang.String arg0);
  public A addToServiceNetwork(java.lang.Integer index,java.lang.String item);
  public A setToServiceNetwork(java.lang.Integer index,java.lang.String item);
  public A addToServiceNetwork(java.lang.String... items);
  public A addAllToServiceNetwork(java.util.Collection<java.lang.String> items);
  public A removeFromServiceNetwork(java.lang.String... items);
  public A removeAllFromServiceNetwork(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getServiceNetwork();
  public java.lang.String getServiceNetwork(java.lang.Integer index);
  public java.lang.String getFirstServiceNetwork();
  public java.lang.String getLastServiceNetwork();
  public java.lang.String getMatchingServiceNetwork(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingServiceNetwork(java.util.function.Predicate<java.lang.String> predicate);
  public A withServiceNetwork(java.util.List<java.lang.String> serviceNetwork);
  public A withServiceNetwork(java.lang.String... serviceNetwork);
  public java.lang.Boolean hasServiceNetwork();
  public A addNewServiceNetwork(java.lang.String arg0);
  public interface ClusterNetworkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterNetworkEntryFluent<io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<N>>{
    public N and();
    public N endClusterNetwork();
    
  }
  public interface MigrationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.NetworkMigrationFluent<io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<N>>{
    public N and();
    public N endMigration();
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/NetworkStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkStatusFluent<A extends io.fabric8.openshift.api.model.NetworkStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToClusterNetwork(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public A setToClusterNetwork(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public A addToClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... items);
  public A addAllToClusterNetwork(java.util.Collection<io.fabric8.openshift.api.model.ClusterNetworkEntry> items);
  public A removeFromClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... items);
  public A removeAllFromClusterNetwork(java.util.Collection<io.fabric8.openshift.api.model.ClusterNetworkEntry> items);
  public A removeMatchingFromClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildClusterNetwork instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> getClusterNetwork();
  public java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> buildClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildClusterNetwork(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildFirstClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildLastClusterNetwork();
  public io.fabric8.openshift.api.model.ClusterNetworkEntry buildMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public java.lang.Boolean hasMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public A withClusterNetwork(java.util.List<io.fabric8.openshift.api.model.ClusterNetworkEntry> clusterNetwork);
  public A withClusterNetwork(io.fabric8.openshift.api.model.ClusterNetworkEntry... clusterNetwork);
  public java.lang.Boolean hasClusterNetwork();
  public A addNewClusterNetwork(java.lang.String cidr,java.lang.Integer hostSubnetLength);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> addNewClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> addNewClusterNetworkLike(io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> setNewClusterNetworkLike(java.lang.Integer index,io.fabric8.openshift.api.model.ClusterNetworkEntry item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editClusterNetwork(java.lang.Integer index);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editFirstClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editLastClusterNetwork();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<A> editMatchingClusterNetwork(java.util.function.Predicate<io.fabric8.openshift.api.model.ClusterNetworkEntryBuilder> predicate);
  public java.lang.Integer getClusterNetworkMTU();
  public A withClusterNetworkMTU(java.lang.Integer clusterNetworkMTU);
  public java.lang.Boolean hasClusterNetworkMTU();
  
  /**
   * This method has been deprecated, please use method buildMigration instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.NetworkMigration getMigration();
  public io.fabric8.openshift.api.model.NetworkMigration buildMigration();
  public A withMigration(io.fabric8.openshift.api.model.NetworkMigration migration);
  public java.lang.Boolean hasMigration();
  public A withNewMigration(java.lang.String networkType);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> withNewMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> withNewMigrationLike(io.fabric8.openshift.api.model.NetworkMigration item);
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editOrNewMigration();
  public io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<A> editOrNewMigrationLike(io.fabric8.openshift.api.model.NetworkMigration item);
  public java.lang.String getNetworkType();
  public A withNetworkType(java.lang.String networkType);
  public java.lang.Boolean hasNetworkType();
  
  /**
   * Method is deprecated. use withNetworkType instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkType(java.lang.String arg0);
  public A addToServiceNetwork(java.lang.Integer index,java.lang.String item);
  public A setToServiceNetwork(java.lang.Integer index,java.lang.String item);
  public A addToServiceNetwork(java.lang.String... items);
  public A addAllToServiceNetwork(java.util.Collection<java.lang.String> items);
  public A removeFromServiceNetwork(java.lang.String... items);
  public A removeAllFromServiceNetwork(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getServiceNetwork();
  public java.lang.String getServiceNetwork(java.lang.Integer index);
  public java.lang.String getFirstServiceNetwork();
  public java.lang.String getLastServiceNetwork();
  public java.lang.String getMatchingServiceNetwork(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingServiceNetwork(java.util.function.Predicate<java.lang.String> predicate);
  public A withServiceNetwork(java.util.List<java.lang.String> serviceNetwork);
  public A withServiceNetwork(java.lang.String... serviceNetwork);
  public java.lang.Boolean hasServiceNetwork();
  public A addNewServiceNetwork(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ClusterNetworkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ClusterNetworkEntryFluent<io.fabric8.openshift.api.model.NetworkStatusFluent.ClusterNetworkNested<N>>{
    public N and();
    public N endClusterNetwork();
    
  }
  public interface MigrationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.NetworkMigrationFluent<io.fabric8.openshift.api.model.NetworkStatusFluent.MigrationNested<N>>{
    public N and();
    public N endMigration();
    
  }
  
}
